{% extends 'base.html' %}
{% load static %}

{% block head %}
  {{ block.super }}
  <style>
    .bg-primary {
      background-color: #003F7A !important;
    }
  </style>
{% endblock %}

{% block content %}
  <kr-app id="app">

  </kr-app>
{% endblock %}
