<html>
  <head c:include="xml/header.html"></head>
  <body>
      <kr-app id="app" b:is_pwa="int(request.user_agent.is_mobile)" b:module="djsamon.static('kirui/js/entrypoint.js')" entrypoint="entrypoint">
        <kr-layout-sidebar>
            <kr-sidebar-header c:include="xml/sidebar_header.html" />
            <kr-sidebar-nav c:include="xml/menu.html" />

            <kr-sidebar-main>
              <div class="row">
                <div class="col-3">
                  <kr-chart-donut b:.values="djsamon.bind_dict(donut)" />
                  <kr-chart-line b:.values="djsamon.bind_dict(line)" style="width: 1000px; height: 500px; display: block;" />
                </div>
              </div>
            </kr-sidebar-main>
        </kr-layout-sidebar>
      </kr-app>
  </body>
</html>