<kr-form b:object="form" label-width="sm-4 md-3 lg-2" field-width="sm-8 md-9 lg-10" action="/backend/form/" id="proba" style="margin-top: 30px;">
        <input type="submit" name="submit" value="Submit" class="btn btn-primary" @click="${ (ev) => { ev.target.closest('kr-form').submit(ev); }}" />
</kr-form>
